@@ -1,12 +1,23 @@
+import io
 import json
 import types
 
-
 from requests.status_codes import codes
 from requests.structures import CaseInsensitiveDict
+from robot.api import logger
 
-from RequestsLibrary.exceptions import UnknownStatusError
 from RequestsLibrary.compat import urlencode, PY3
+from RequestsLibrary.exceptions import UnknownStatusError
+
+
+class WritableObject:
+    """ HTTP stream handler """
+
+    def __init__(self):
+        self.content = []
+
+    def write(self, string):
+        self.content.append(string)
 
 
 def parse_named_status(status_code):
@@ -30,7 +41,7 @@ def merge_headers(session, headers):
         # have priority and can override values
         merged_headers = session.headers.copy()
 
-    # Make sure merged_headers are CaseIsensitiveDict
+    # Make sure merged_headers are CaseInsensitiveDict
     if not isinstance(merged_headers, CaseInsensitiveDict):
         merged_headers = CaseInsensitiveDict(merged_headers)
 
@@ -70,6 +81,14 @@ def is_string_type(data):
     return False
 
 
+def is_file_descriptor(fd):
+    if PY3 and isinstance(fd, io.IOBase):
+        return True
+    if not PY3 and isinstance(fd, file): # noqa
+        return True
+    return False
+
+
 def utf8_urlencode(data):
     if is_string_type(data):
         return data.encode('utf-8')
@@ -85,25 +104,11 @@ def utf8_urlencode(data):
     return urlencode(utf8_data)
 
 
-def format_data_to_log_string_according_to_headers(session, data, headers):
-    data_str = None
-    # Merged headers are already case insensitive
-    headers = merge_headers(session, headers)
-
-    if data is not None and headers is not None and 'Content-Type' in headers:
-        if (headers['Content-Type'].find("application/json") != -1) or \
-                (headers['Content-Type'].find("application/x-www-form-urlencoded") != -1):
-            if isinstance(data, bytes):
-                data_str = data.decode('utf-8')
-            else:
-                data_str = data
-        else:
-            data_str = "<" + headers['Content-Type'] + ">"
-
-    return data_str
-
-
 def format_data_according_to_header(session, data, headers):
+    # when data is an open file descriptor we ignore it
+    if is_file_descriptor(data):
+        return data
+
     # Merged headers are already case insensitive
     headers = merge_headers(session, headers)
 
@@ -118,3 +123,19 @@ def format_data_according_to_header(session, data, headers):
         data = utf8_urlencode(data)
 
     return data
+
+
+def warn_if_equal_symbol_in_url(func):
+    def decorator(*args, **kwargs):
+        try:
+            args[2]
+        except IndexError:
+            if 'url' not in kwargs:
+                logger.warn("You might have an = symbol in url."
+                            " You better place 'url=' before, example: 'url=/your-url/foo?param=a'"
+                            " or use '/your-url/foo  params=param=a' or escape it")
+
+        return func(*args, **kwargs)
+    decorator.__name__ = func.__name__
+    decorator.__doc__ = func.__doc__
+    return decorator
